@@ -35,12 +35,12 @@ class BaseCollectorPlugin(HopprPlugin):
 
     @staticmethod
     def _get_repo_search_list(comp: Component) -> list[str]:
-        repo_list = []
+        repo_list: list[str] = []
         for prop in comp.properties or []:
             if prop.name == constants.BomProps.COMPONENT_SEARCH_SEQUENCE:
                 search_sequence_str = json.loads(prop.value or '{"version": "v1", "repositories": []}')
                 search_sequence = SearchSequence.parse_obj(search_sequence_str)
-                repo_list.extend(search_sequence.repositories)
+                repo_list.extend(map(str, search_sequence.repositories))
 
         return repo_list
 
@@ -216,7 +216,6 @@ class BaseCollectorPlugin(HopprPlugin):
             constants.BomProps.COLLECTION_PLUGIN,
             constants.BomProps.COLLECTION_TIMETAG,
         ]:
-
             if req_prop.value not in [prop.name for prop in result.return_obj.properties or []]:
                 missing_props.append(req_prop.value)
 
@@ -242,8 +241,8 @@ class SerialCollectorPlugin(BaseCollectorPlugin):
         """
 
     @final
-    @hoppr_process
     @hoppr_ignore_excluded
+    @hoppr_process
     def process_component(self, comp: Component) -> Result:
         """
         Copy a component to the local collection directory structure
@@ -300,8 +299,8 @@ class BatchCollectorPlugin(BaseCollectorPlugin):
         """
 
     @final
-    @hoppr_process
     @hoppr_ignore_excluded
+    @hoppr_process
     def process_component(self, comp: Component) -> Result:
         """
         Copy a component to the local collection directory structure
