@@ -12,25 +12,19 @@ from abc import ABC, abstractmethod
 from os import PathLike
 from typing import Any, Callable, Dict, List, Optional
 
-from packageurl import PackageURL
-
 from hoppr import plugin_utils
 from hoppr.mem_logger import MemoryLogger
 from hoppr.models import HopprContext
 from hoppr.models.transfer import ComponentCoverage
 from hoppr.models.types import BomAccess
 from hoppr.result import Result
-from hoppr.utils import obscure_passwords
+from hoppr.utils import get_package_url, obscure_passwords
 
 
 def _get_component(*args, **kwargs) -> Optional[Any]:
     # TODO: This will only utilize the first Component found in 1) args, 2) kwargs  # pylint: disable=fixme
     # and assumes all plugins operate this way
-    comp = None
-    for arg in args:
-        if type(arg).__name__ == "Component":
-            comp = arg
-            break
+    comp = next((arg for arg in args if type(arg).__name__ == "Component"), None)
 
     if comp is None:
         for value in kwargs.values():
@@ -65,7 +59,7 @@ def hoppr_process(func: Callable) -> Callable:
                 result = Result.fail("No purl supplied for component")
 
             else:
-                purl_type = PackageURL.from_string(comp.purl).type
+                purl_type = get_package_url(comp.purl).type
 
                 if not self.supports_purl_type(purl_type):
                     return Result.skip(f"Class {self.__class__.__name__} does not support purl type {purl_type}")
@@ -77,7 +71,6 @@ def hoppr_process(func: Callable) -> Callable:
                 )
 
         if result is None:
-
             # Only check for missing commands if func has been overridden
             if func.__module__ != HopprPlugin.__module__:
                 command_result = plugin_utils.check_for_missing_commands(self.required_commands)
@@ -118,7 +111,6 @@ def hoppr_rerunner(method: Callable) -> Callable:
 
     @functools.wraps(method)
     def wrapper(self, *args, **kwargs) -> Result:
-
         log = self.get_logger()
 
         result = Result.fail(message="Context max_attempts must be a positive integer.")
@@ -162,9 +154,11 @@ def hoppr_ignore_excluded(func: Callable) -> Callable:
 
     @functools.wraps(func)
     def wrapper(self, *args, **kwargs) -> Result:
-
         comp = _get_component(*args, **kwargs)
-        if comp is not None and str(comp.scope) in ('excluded', 'Scope.excluded'):
+        if comp is not None and str(comp.scope) in {
+            'excluded',
+            'Scope.excluded',
+        }:
             return Result.excluded()
         return func(self, *args, **kwargs)
 
