@@ -19,6 +19,7 @@ from packageurl import PackageURL
 from requests.auth import HTTPBasicAuth
 
 import hoppr.net
+import hoppr.utils
 
 from hoppr import __version__
 from hoppr.base_plugins.collector import BatchCollectorPlugin
@@ -44,12 +45,10 @@ def _artifact_string(purl: PackageURL) -> str:
 
 def _is_rpm_repo(repo_url: str) -> bool:
     url = RepositoryUrl(url=repo_url) / "repodata/repomd.xml"
-
     basic_auth = None
     creds = Credentials.find(repo_url)
     if creds is not None:
         basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password.get_secret_value())
-
     for attempt in range(3):
         if attempt > 0:
             sleep(5)
@@ -77,6 +76,18 @@ def _repo_proxy(url: str) -> str:
     return proxy
 
 
+def _clear_cache(search_root: Path):
+    """
+    Clear the cache for a given Path.
+    """
+    temp_paths = list(search_root.rglob("hoppr-tmp-*"))
+    for folder in temp_paths:
+        if os.path.isdir(folder):
+            shutil.rmtree(folder, ignore_errors=True)
+        else:
+            folder.unlink()
+
+
 class CollectDnfPlugin(BatchCollectorPlugin):
     """
     Collector plugin for DNF packages
@@ -115,14 +126,12 @@ class CollectDnfPlugin(BatchCollectorPlugin):
 
         command = [*self.base_command, "repoquery", "--location", artifact]
         run_result = self.run_command(command, self.password_list)
-
         # If RPM URL not found, no need to try downloading it
         if run_result.returncode != 0 or len(run_result.stdout.decode("utf-8")) == 0:
             msg = f"{self.required_commands[0]} failed to locate package for {purl}"
             self.get_logger().debug(msg=msg, indent_level=2)
 
             raise HopprPluginError(msg)
-
         # Taking the first URL if multiple are returned
         return run_result.stdout.decode("utf-8").strip().split("\n")[0]
 
@@ -140,10 +149,13 @@ class CollectDnfPlugin(BatchCollectorPlugin):
         repo_config = ConfigParser()
         repo_config["main"] = dict(cachedir=f"{self.config_file.parent / 'cache'}")
 
+        # Clear out cache before starting the pre_stage_process
+        search_root = self.config_file.parent / "cache"
+        _clear_cache(search_root)
+
         for idx, repo in enumerate(self.context.repositories[PurlType.RPM]):
             temp_repo = f"hoppr-tmp-{idx}"
             creds = Credentials.find(f"{repo.url}")
-
             if not _is_rpm_repo(f"{repo.url}"):
                 self.get_logger().warning(
                     f"Repo {repo.url} is not an RPM repository (repomd.xml file not found), will not be searched"
@@ -183,7 +195,6 @@ class CollectDnfPlugin(BatchCollectorPlugin):
             # Create repo config dir in user directory
             config_dir = self.config_file.parent
             config_dir.mkdir(parents=True, exist_ok=True)
-
             with self.config_file.open(mode="w+", encoding="utf-8") as repo_file:
                 repo_config.write(repo_file, space_around_delimiters=False)
         except OSError as ex:
@@ -195,10 +206,9 @@ class CollectDnfPlugin(BatchCollectorPlugin):
             "check-update",
             "makecache",
         ]
-
         # Generate cache to use when downloading components
         result = self.run_command(command, self.password_list)
-
+        self.get_logger().debug(msg=(f"Return Code: {result.returncode}"), indent_level=2)
         if result.returncode != 0:
             return Result.fail(message="Failed to populate DNF cache.")
 
@@ -285,4 +295,7 @@ class CollectDnfPlugin(BatchCollectorPlugin):
             except FileNotFoundError as ex:
                 return Result.fail(f"Failed to remove temporary DNF config file: {ex}")
 
+        # Clear cache at the end of the post stage process
+        _clear_cache(search_root)
+
         return Result.success()
