@@ -4,10 +4,9 @@ Collector plugin for git repositories
 from __future__ import annotations
 
 import os
-import pathlib
 import re
 
-from typing import Any
+from pathlib import Path
 
 from packageurl import PackageURL  # type: ignore[import]
 
@@ -16,6 +15,7 @@ from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.models import HopprContext
 from hoppr.models.credentials import CredentialRequiredService
+from hoppr.models.manifest import Component
 from hoppr.result import Result
 
 
@@ -38,12 +38,11 @@ class CollectGitPlugin(SerialCollectorPlugin):
 
     def __init__(self, context: HopprContext, config: dict | None = None) -> None:
         super().__init__(context=context, config=config)
-        if self.config is not None:
-            if "git_command" in self.config:
-                self.required_commands = [self.config["git_command"]]
+        if self.config is not None and "git_command" in self.config:
+            self.required_commands = [self.config["git_command"]]
 
     @hoppr_rerunner
-    def collect(self, comp: Any, repo_url: str, creds: CredentialRequiredService | None = None):
+    def collect(self, comp: Component, repo_url: str, creds: CredentialRequiredService | None = None) -> Result:
         """
         Collect git repository
         """
@@ -68,16 +67,23 @@ class CollectGitPlugin(SerialCollectorPlugin):
 
         return Result.success(return_obj=comp)
 
-    def git_clone(self, tmp_dir, source_url, source_creds, comp: Any):
-        """Git clone"""
-
+    def git_clone(
+        self,
+        tmp_dir: Path,
+        source_url: str,
+        source_creds: CredentialRequiredService | None,
+        comp: Component,
+    ) -> Result:
+        """
+        Git clone
+        """
         git_src = source_url
-        password_list = []
+        password_list: list[str] = []
         if re.match("^https?://", git_src) and source_creds is not None:
             git_src = git_src.replace("://", f"://{source_creds.username}@", 1)
             if source_creds.password:
-                git_src = git_src.replace("@", f":{source_creds.password}@")
-                password_list = [source_creds.password]
+                git_src = git_src.replace("@", f":{source_creds.password.get_secret_value()}@")
+                password_list = [source_creds.password.get_secret_value()]
 
         if git_src.startswith("ssh://") and source_creds is not None:
             git_src = git_src.replace("ssh://", f"ssh://{source_creds.username}@")
@@ -85,10 +91,9 @@ class CollectGitPlugin(SerialCollectorPlugin):
         if not git_src.endswith(".git"):
             git_src += ".git"
 
-        opts = []
+        opts: list[str] = []
         if str(comp.version).strip():
-            opts.append("--branch")
-            opts.append(str(comp.version))
+            opts.extend(("--branch", str(comp.version)))
 
         # Default depth
         depth = "1"
@@ -98,8 +103,7 @@ class CollectGitPlugin(SerialCollectorPlugin):
 
         # Recognize the 'all' keyword as requesting all history
         if depth.lower() != "all":
-            opts.append("--depth")
-            opts.append(depth)
+            opts.extend(("--depth", depth))
 
         # Command
         command = [self.required_commands[0], "clone", *opts, git_src]
@@ -117,16 +121,18 @@ class CollectGitPlugin(SerialCollectorPlugin):
 
         return Result.success()
 
-    def git_update(self, tmp_dir, name_git):
-        """Git update-server-info"""
-
-        repo_dir = os.path.join(pathlib.Path(tmp_dir), name_git)
+    def git_update(self, tmp_dir: Path, name_git: str) -> Result:
+        """
+        Git update-server-info
+        """
+        repo_dir = tmp_dir / name_git
 
         # Make the clone usable as a remote
         result = self.run_command(
             [self.required_commands[0], "update-server-info"],
             cwd=repo_dir,
         )
+
         if result.returncode != 0:
             msg = "Failed to make the clone usable as a remote"
             self.get_logger().debug(msg=msg, indent_level=2)
