@@ -5,9 +5,9 @@ from __future__ import annotations
 
 from pathlib import Path
 
-from packageurl import PackageURL
+import hoppr.utils
 
-from hoppr import __version__, utils
+from hoppr import __version__
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.exceptions import HopprLoadDataError
@@ -36,10 +36,7 @@ class CollectHelmPlugin(SerialCollectorPlugin):
 
         self.create_logger()
 
-        if self.config is not None:
-            if "helm_command" in self.config:
-                self.required_commands = [self.config["helm_command"]]
-
+        self.required_commands = (self.config or {}).get("helm_command", self.required_commands)
         self.base_command = [self.required_commands[0], "fetch"]
 
         system_repos_file = Path.home() / ".config" / "helm" / "repositories.yaml"
@@ -47,7 +44,7 @@ class CollectHelmPlugin(SerialCollectorPlugin):
             system_repos: list[dict[str, str]] = []
 
             try:
-                system_repos_dict = utils.load_file(input_file_path=system_repos_file)
+                system_repos_dict = hoppr.utils.load_file(input_file_path=system_repos_file)
                 if not isinstance(system_repos_dict, dict):
                     raise HopprLoadDataError("Incorrect format.")
 
@@ -64,10 +61,11 @@ class CollectHelmPlugin(SerialCollectorPlugin):
         Collect helm chart
         """
 
-        purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
+        purl = hoppr.utils.get_package_url(comp.purl)
 
         target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.name}_{purl.version}")
 
+        run_result = None
         for subdir in ["", purl.name]:
             source_url = RepositoryUrl(url=repo_url) / subdir
 
@@ -107,6 +105,11 @@ class CollectHelmPlugin(SerialCollectorPlugin):
 
                 return Result.success(return_obj=comp)
 
-        msg = f"Failed to download {purl.name} version {purl.version} helm chart"
+        msg = f"Failed to download {purl.name} version {purl.version} helm chart from {repo_url}."
+
+        if run_result is not None and "404 Not Found" in str(run_result.stderr):
+            self.get_logger().debug(msg=msg, indent_level=2)
+            return Result.fail(f"{msg} Chart not found.")
+
         self.get_logger().debug(msg=msg, indent_level=2)
         return Result.retry(msg)
