@@ -119,14 +119,12 @@ class CollectNexusSearch(SerialCollectorPlugin):
 
         subdir = None
         match purl.type:
-            case "docker" | "generic" | "maven" | "rpm":
+            case "docker" | "generic" | "maven" | "raw" | "rpm":
                 subdir = path
             case "helm" | "pypi":
                 subdir = f"{purl.name}_{purl.version}"
 
-        target_dir = self.directory_for(purl.type, nexus_repo, subdir=subdir)
-
-        return target_dir
+        return self.directory_for(purl.type, nexus_repo, subdir=subdir)
 
     @staticmethod
     def is_nexus_instance(repo_url: str, auth: HTTPBasicAuth | None = None) -> bool:
@@ -172,7 +170,7 @@ class CollectNexusSearch(SerialCollectorPlugin):
                 nexus_format = "rubygems"
             case "golang":
                 nexus_format = "go"
-            case "generic":
+            case "generic" | "raw":
                 nexus_format = "raw"
             case "maven":
                 nexus_format = "maven2"
