@@ -40,6 +40,11 @@ class CollectPypiPlugin(SerialCollectorPlugin):
         self.manifest_repos: list[str] = []
         self.password_list: list[str] = []
         self.base_command = [self.required_commands[0], "-m", "pip"]
+        # Allow users to define their own pip command...
+        # i.e. python3.6 -m pip
+        if self.config is not None:
+            if "pip_command" in self.config:
+                self.base_command = str(self.config["pip_command"]).split(" ", maxsplit=-1)
 
     def _run_cmd_wrapper(  # pylint: disable=too-many-arguments
         self, command, password_list, param: str, pkg_format: str, log_if_error: str
@@ -111,11 +116,16 @@ class CollectPypiPlugin(SerialCollectorPlugin):
 
         base_error_msg = f"Failed to download {purl.name} version {purl.version}"
 
-        if self.collect_binary_only(command, password_list, base_error_msg):  # pylint: disable=no-else-return
+        collection_type = "ANY"
+
+        if self.config is not None and "type" in self.config:
+            collection_type = str(self.config["type"]).lower()
+
+        if (collection_type != "source") and self.collect_binary_only(command, password_list, base_error_msg):
             self.set_collection_params(comp, repo_url, target_dir)
             return Result.success(return_obj=comp)
-        elif self.collect_source(command, password_list, base_error_msg):  # pylint: disable=no-else-return
+        if (collection_type != "binary") and self.collect_source(command, password_list, base_error_msg):
             self.set_collection_params(comp, repo_url, target_dir)
             return Result.success(return_obj=comp)
-        else:
-            return Result.retry(f"{base_error_msg} as either binary or source.")
+
+        return Result.retry(f"{base_error_msg} with collection type: {collection_type}.")
