@@ -1,16 +1,17 @@
 """
 Collector plugin for Yum packages
 """
+from __future__ import annotations
 
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any
 
-from packageurl import PackageURL  # type: ignore
+from packageurl import PackageURL
 
 from hoppr import __version__
 from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
-from hoppr.context import Context
+from hoppr.models import HopprContext
 from hoppr.result import Result
 
 
@@ -34,12 +35,12 @@ class CollectYumPlugin(SerialCollectorPlugin):
 
     supported_purl_types = ["rpm"]
     required_commands = ["yumdownloader"]
-    products: List[str] = ["rpm/*"]
+    products: list[str] = ["rpm/*"]
 
     def get_version(self) -> str:
         return __version__
 
-    def __init__(self, context: Context, config: Optional[Dict] = None) -> None:
+    def __init__(self, context: HopprContext, config: dict | None = None) -> None:
         super().__init__(context=context, config=config)
         if self.config is not None:
             if "yumdownloader_command" in self.config:
@@ -51,10 +52,7 @@ class CollectYumPlugin(SerialCollectorPlugin):
         Copy a component to the local collection directory structure
         """
 
-        purl = PackageURL.from_string(comp.purl)
-        result = self.check_purl_specified_url(purl, repo_url)
-        if not result.is_success():
-            return result
+        purl: PackageURL = PackageURL.from_string(comp.purl)  # pyright: ignore[reportGeneralTypeIssues]
         artifact = _artifact_string(purl)
 
         self.get_logger().info(msg=f"Copying yum package from {comp.purl}", indent_level=2)
@@ -73,7 +71,7 @@ class CollectYumPlugin(SerialCollectorPlugin):
         if run_result.returncode != 0:
             msg = (
                 f"{self.required_commands[0]} failed to locate package for {comp.purl}, "
-                + f"return_code={run_result.returncode}"
+                f"return_code={run_result.returncode}"
             )
             self.get_logger().debug(msg=msg, indent_level=2)
 
@@ -110,4 +108,6 @@ class CollectYumPlugin(SerialCollectorPlugin):
             msg = f"Failed to download Yum artifact {purl.name} version {purl.version} "
             return Result.retry(message=msg)
 
-        return Result.success()
+        self.set_collection_params(comp, repo_url, target_dir)
+
+        return Result.success(return_obj=comp)
