@@ -24,6 +24,7 @@ class DeltaSbom(HopprPlugin):
     """
 
     bom_access = BomAccess.FULL_ACCESS
+    products: list[str] = ["generic/_metadata_/_previous_bom.json"]
 
     def get_version(self) -> str:
         return __version__
@@ -50,6 +51,12 @@ class DeltaSbom(HopprPlugin):
 
         previous_sbom = self._get_previous_bom(previous_source)  # pyright: ignore[reportGeneralTypeIssues]
 
+        target_dir = self.context.collect_root_dir / "generic" / "_metadata_"
+        target_dir.mkdir(parents=True, exist_ok=True)
+
+        with (target_dir / "_previous_bom.json").open(mode="w", encoding="utf-8") as bom_data:
+            bom_data.write(previous_sbom.json(exclude_none=True, by_alias=True, indent=2))
+
         delta_sbom = deepcopy(self.context.delivered_sbom)
         delta_sbom.components = []
 
@@ -86,7 +93,8 @@ class DeltaSbom(HopprPlugin):
             pass
 
         with tarfile.open(source) as tar:
-            buffer = tar.extractfile(tarfile.TarInfo(str(Path("generic") / "_metadata_" / "_consolidated_bom.json")))
+            buffer = tar.extractfile("./generic/_metadata_/_consolidated_bom.json")
+
             if buffer is None:
                 raise HopprError("Unable to extract BOM file from tar")
 
