@@ -5,6 +5,7 @@ import logging
 import sys
 
 from pathlib import Path
+from posixpath import sep
 from typing import List, Optional
 
 from typer import Exit, echo, prompt
@@ -34,9 +35,14 @@ def bundle(  # pylint: disable=too-many-arguments,too-many-locals
     Run the stages specified in the transfer config
     file on the content specified in the manifest
     """
+    echo(
+        f"Loading {str(manifest_file).rsplit(str(sep), maxsplit=1)[-1]} and"
+        f"{str(transfer_file).rsplit(str(sep), maxsplit=1)[-1]} files..."
+    )
     metadata_files = [manifest_file, transfer_file]
 
     if credentials_file is not None:
+        echo(f"Loading {str(credentials_file).rsplit(str(sep), maxsplit=1)[-1]} file...")
         metadata_files.append(credentials_file)
 
     log_level = logging.DEBUG if verbose else logging.INFO
