@@ -5,7 +5,7 @@ from __future__ import annotations
 
 from typing import Literal
 
-from pydantic import Extra, Field
+from pydantic import Extra, Field, validator
 from pydantic_yaml import YamlModel
 
 
@@ -28,6 +28,7 @@ class HopprBaseModel(YamlModel):
         """Config for HopprBaseModel"""
 
         allow_population_by_field_name = True
+        arbitrary_types_allowed = True
         extra = Extra.forbid
         use_enum_values = True
 
@@ -43,8 +44,14 @@ class HopprBaseSchemaModel(HopprBaseModel):
     Base Hoppr config file schema model
     """
 
-    kind: Literal["Credentials", "Manifest", "Transfer", "credentials", "manifest", "transfer"] = Field(
-        ..., description="Data model/schema kind"
-    )
+    kind: Literal["Credentials", "Manifest", "Transfer"] = Field(..., description="Data model/schema kind")
     metadata: Metadata | None = Field(None, description="Metadata for the file")
     schema_version: str = Field(..., alias="schemaVersion", title="Schema Version")
+
+    @validator("kind", allow_reuse=True, pre=True)
+    @classmethod
+    def validate_kind(cls, kind: str) -> str:
+        """
+        Return supplied `kind` value with only first letter capitalized
+        """
+        return kind.capitalize()
