@@ -33,19 +33,20 @@ class CredentialRequiredService(HopprBaseModel):
         """
         Dynamically parse credentials using specified environment variables
         """
-        user_env = values.get("user_env")
-        if user_env is not None:
-            username = os.environ.get(values["user_env"], "")
-            assert len(username) > 0
-            values["user"] = username
+        try:
+            if (user_env := values.get("user_env")) is not None:
+                if username := os.environ[user_env]:
+                    values["user"] = username
+                else:
+                    raise ValueError(user_env)
 
-        pass_env = values.get("pass_env", "")
-        assert len(pass_env) > 0
-
-        password = os.environ.get(pass_env, "")
-        assert len(password) > 0
-
-        values["password"] = SecretStr(password)
+            if (pass_env := values.get("pass_env")) is not None:
+                if password := os.environ[pass_env]:
+                    values["password"] = SecretStr(password)
+                else:
+                    raise ValueError(pass_env)
+        except (KeyError, ValueError) as ex:
+            raise ValueError(f"The environment variable {ex} must be set with a non-empty string") from ex
 
         return values
 
