@@ -107,7 +107,7 @@ class SearchSequence(HopprBaseModel):
     """
 
     version: Literal["v1"]
-    repositories: list[HttpUrl | FileUrl | str] = []
+    repositories: list[RepositoryUrl | str] = []
 
 
 IncludeRef = Annotated[LocalFile | UrlFile, Field(..., description="Reference to a local or remote manifest file")]
