@@ -25,7 +25,8 @@ class StageName(ConstrainedStr):
     Constrained string type for stage key name
     """
 
-    regex: Pattern[str] = re.compile(pattern=r"^[A-Za-z_][\w\s]*$")
+    # Match any string without whitespace for stagenames
+    regex: Pattern[str] = re.compile(pattern=r"^\S+")
     min_length: int = 1
 
 
