@@ -58,6 +58,7 @@ class PurlType(YamlStrEnum):
     MAVEN = "maven"
     NPM = "npm"
     PYPI = "pypi"
+    RAW = "raw"
     REPO = "repo"
     RPM = "rpm"
 
@@ -95,9 +96,6 @@ class RepositoryUrl(HopprBaseModel):
         if url.endswith(":"):
             url = f"{url}//"
 
-        if "://" not in url:
-            url = f"http://{url}"
-
         if not (
             match := re.search(
                 pattern=(
