@@ -13,7 +13,7 @@ import tempfile
 import time
 import uuid
 
-from concurrent.futures import Future, ProcessPoolExecutor
+from concurrent.futures import Future, ThreadPoolExecutor, as_completed
 from copy import deepcopy
 from datetime import datetime
 from multiprocessing import cpu_count
@@ -119,28 +119,37 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
 
         return result
 
-    def _run_all(self, method_name: str):
+    def _populate_futures(self, method_name: str) -> tuple[int, int]:
         """
         Run the named method for all plugins.  If appropriate to the method, run it for
         all components for all plug-ins.
         """
-        # Map to allow access to the arguments that went into a future call
         future_argument_map: dict[Future[Result], tuple[Plugin, Component | None]] = {}
 
-        with ProcessPoolExecutor(max_workers=self.context.max_processes) as executor:
+        with ThreadPoolExecutor(max_workers=self.context.max_processes) as executor:
+            failures = 0
+            retries = 0
             for plugin in self.plugin_ref_list:
+                plugin_cls = plugin_class(plugin.name)
+
+                if getattr(plugin_cls, method_name) == getattr(HopprPlugin, method_name):
+                    continue
+
                 if method_name in self.component_based_methods:
                     # Create one concurrent future object to run this method for each component
                     for component in self.context.delivered_sbom.components or []:
-                        future_proc = executor.submit(
-                            _run_plugin,
-                            plugin_name=plugin.name,
-                            context=self.context,
-                            config=plugin.config,
-                            method_name=method_name,
-                            component=component,
-                        )
-                        future_argument_map[future_proc] = (plugin, component)
+                        if component.purl:
+                            instance = plugin_instance(plugin.name, self.context, plugin.config)
+                            if instance.supports_purl_type(PackageURL.from_string(component.purl).type):
+                                future_proc = executor.submit(
+                                    _run_plugin,
+                                    plugin_name=plugin.name,
+                                    context=self.context,
+                                    config=plugin.config,
+                                    method_name=method_name,
+                                    component=component,
+                                )
+                                future_argument_map[future_proc] = (plugin, component)
                 else:
                     # Create a concurrent future object to run this method
                     future_proc = executor.submit(
@@ -153,40 +162,66 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
                     )
                     future_argument_map[future_proc] = (plugin, None)
 
-            # Save all the results, count failures and retries
-            # Note: future.results() blocks until the process is complete
-            need_method_label = True
-            failures = 0
-            retries = 0
+            fail, retry = self.process_status(
+                future_argument_map=future_argument_map, method_name=method_name, failures=failures, retries=retries
+            )
 
-            for future_proc, (plugin, comp) in future_argument_map.items():
-                future_result: Result = future_proc.result()
-                if not future_result.is_skip():
-                    if need_method_label:
-                        echo(f"   Beginning method {method_name}")
-                        need_method_label = False
+            failures += fail
+            retries += retry
 
-                    plugin_cls = plugin_class(plugin.name)
+        return failures, retries
 
+    def process_status(
+        self,
+        future_argument_map: dict[Future[Result], tuple[Plugin, Component | None]],
+        method_name: str,
+        failures: int,
+        retries: int,
+    ) -> tuple[int, int]:
+        """
+        Print processing results.
+        """
+        need_method_label = True
+        for future in as_completed(future_argument_map):
+            # retrieve the result
+            (plugin, comp) = future_argument_map[future]
+            future_result: Result = future.result()
+            if not future_result.is_skip():
+                if need_method_label:
+                    echo(f"   Beginning method {method_name}")
+                    need_method_label = False
+
+                plugin_cls = plugin_class(plugin.name)
+
+                if not future_result.is_excluded():
                     self._save_result(method_name, plugin_cls.__name__, future_result, comp)
-                    self._report_result(plugin_cls.__name__, comp, future_result)
                     self._update_bom(future_result.return_obj, comp)
-                    ReportGenerator.report_gen_list.append(
-                        Report(
-                            uuid.uuid4(),
-                            plugin_cls.__name__,
-                            self.stage_id,
-                            future_result.status,
-                            future_result.message,
-                            method_name,
-                            comp,
-                        )
-                    )
+                self._report_result(plugin_cls.__name__, comp, future_result)
 
-                    if future_result.is_fail():
-                        failures += 1
-                    if future_result.is_retry():
-                        retries += 1
+                ReportGenerator.report_gen_list.append(
+                    Report(
+                        uuid.uuid4(),
+                        plugin_cls.__name__,
+                        self.stage_id,
+                        future_result.status,
+                        future_result.message,
+                        method_name,
+                        comp,
+                    )
+                )
+
+                if future_result.is_fail():
+                    failures += 1
+                if future_result.is_retry():
+                    retries += 1
+        return failures, retries
+
+    def _run_all(self, method_name: str):
+        """
+        Run the named method for all plugins and process results
+        """
+
+        failures, retries = self._populate_futures(method_name)
 
         if method_name in self.component_based_methods:
             failures += self._check_component_coverage(method_name)
@@ -224,13 +259,16 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
 
     def _check_component_coverage(self, method_name: str) -> int:
         result_count: dict[str | None, int] = {}
-        for (_, purl, _) in self.results.get(method_name, []):
+        for _, purl, _ in self.results.get(method_name, []):
             result_count[purl] = result_count.get(purl, 0) + 1
 
         additional_failures = 0
         for component in self.context.delivered_sbom.components or []:
             count = result_count.get(component.purl, 0)
-            if not self.required_coverage.accepts_count(count):
+            if not self.required_coverage.accepts_count(count) and str(component.scope) not in {
+                'excluded',
+                'Scope.excluded',
+            }:
                 bad_comp_result = Result.fail(
                     f"Component processed {count} times, {self.required_coverage.name} coverage required"
                 )
@@ -398,6 +436,7 @@ class HopprProcessor:  # pylint: disable=too-many-instance-attributes
         shutil.copyfile(file_name, f"{target}")
 
     def _collect_manifest_metadata(self, manifest: ManifestFile, target_dir: str | PathLike[str]) -> None:
+        echo(f"Loading {len(manifest.includes)} includes from manifest...")
         for include_ref in manifest.includes:
             include = Manifest.loaded_manifests[include_ref]
             include_dict = include_ref.dict()
@@ -412,6 +451,7 @@ class HopprProcessor:  # pylint: disable=too-many-instance-attributes
             with target_file.open(mode="w+", encoding="utf-8") as output_file:
                 output_file.write(include.yaml(by_alias=True, exclude_unset=True, indent=True))
 
+        echo(f"Loading {len(manifest.sboms)} sboms from manifest...")
         for sbom_ref in manifest.sboms:
             sbom = Sbom.loaded_sboms[sbom_ref]
             sbom_dict = sbom_ref.dict()
@@ -559,7 +599,7 @@ class HopprProcessor:  # pylint: disable=too-many-instance-attributes
 
             self.context = HopprContext(
                 collect_root_dir=Path(collection_root).resolve(),
-                consolidated_sbom=Sbom.consolidated_sbom,
+                consolidated_sbom=deepcopy(Sbom.consolidated_sbom),
                 credential_required_services=getattr(self.credentials, "credential_required_services", None),
                 delivered_sbom=deepcopy(Sbom.consolidated_sbom),
                 log_level=self.log_level,
@@ -590,6 +630,16 @@ class HopprProcessor:  # pylint: disable=too-many-instance-attributes
             self._collect_consolidated_bom()
             self.in_toto_links.record_stage_stop("_collect_metadata")
 
+            # Reset some class variables (we should refactor to use instance variables, see issue
+            # https://gitlab.com/hoppr/hoppr/-/issues/230) so that:
+            #   1: The consolidated bom cannot be modified
+            #   2: Plug-ins may choose to load other manifests.
+            del Sbom.consolidated_sbom
+            Component.component_lookup = {}
+            Component.components = []
+            Component.properties = []
+            Manifest.loaded_manifests = {}
+
             msg = f"Beginning Hoppr Process execution, max_processes={self.context.max_processes}"
             self.logger.info(msg=msg)
             echo(message=msg)
